translate.misc.xmlwrapper

Package translate :: Package misc :: Module xmlwrapper |
[hide private]
[frames] | no frames]

# Module xmlwrapper

source code

simpler wrapper to the elementtree XML parser

Classes | [hide private]
| XMLWrapper simple wrapper for xml objects

Functions | [hide private]
makefixtagproc(namespacemap) this constructs an alternative fixtag procedure that will use appropriate names for namespaces... | source code
splitnamespace(fulltag) | source code
BuildTree(xmlstring) | source code
MakeElement(tag, attrib=`{``}`, **extraargs) | source code

Imports: ElementTree, expat, basicfixtag